@@ -77,7 +77,7 @@ my $ACTION_R = qr/\w+/;
 my $EXCLUDE_R = qr/if\s+\[\s+-x\s+\S*update-rc\.d/;
 
 sub run {
-    my (undef, undef, $info) = @_;
+    my ($pkg, undef, $info) = @_;
     my $initd_dir = $info->index_resolved_path('etc/init.d/');
     my $postinst = $info->control_index('postinst');
     my $preinst = $info->control_index('preinst');
@@ -86,6 +86,11 @@ sub run {
 
     my (%initd_postinst, %initd_postrm);
 
+    # These will never be regular initscripts. (see #918459 & #933383)
+    return if $pkg eq 'initscripts';
+
+    check_missing_script($info);
+
     # read postinst control file
     if ($postinst and $postinst->is_file and $postinst->is_open_ok) {
         my $fd = $postinst->open;
@@ -191,7 +196,7 @@ sub run {
             not $initd_path
             or (    not $info->is_conffile($initd_path->name)
                 and not $initd_path->is_symlink)
-          ) {
+        ) {
             tag 'init.d-script-not-marked-as-conffile',
               "etc/init.d/$initd_file";
         }
@@ -200,6 +205,7 @@ sub run {
         # other issues if it was included in the package.
         check_init($initd_path, $info);
     }
+    check_defaults($info);
 
     return unless $initd_dir and $initd_dir->is_dir;
 
@@ -247,12 +253,14 @@ sub check_init {
     my $fd = $initd_path->open;
     while (my $l = <$fd>) {
         if ($. == 1) {
-            if ($l =~ m,^\#!\s*(/usr/[^\s]+),) {
-                tag 'init.d-script-uses-usr-interpreter',$initd_path, $1;
-            } elsif ($l =~ m{^ [#]! \s* /lib/init/init-d-script}xsm) {
+            if ($l
+                =~ m{^ [#]! \s* (?:/usr/bin/env)? \s* /lib/init/init-d-script}xsm
+            ) {
                 for my $arg (qw(start stop restart force-reload status)) {
                     $tag{$arg} = 1;
                 }
+            } elsif ($l =~ m,^\#!\s*(/usr/[^\s]+),) {
+                tag 'init.d-script-uses-usr-interpreter',$initd_path, $1;
             }
         }
         if ($l =~ m/Please remove the "Author" lines|Example initscript/) {
@@ -402,7 +410,9 @@ sub check_init {
             my $base = $initd_path->basename;
             if (none { $base eq $_ } qw(killprocs sendsigs halt reboot)) {
                 my @missing = grep { !defined $stop{$_} } qw(0 1 6);
-                tag 'init.d-script-possible-missing-stop',$initd_path,@missing;
+                my $start = join(' ', sort keys %start);
+                tag 'init.d-script-possible-missing-stop',$initd_path,@missing
+                  unless $start eq 's';
             }
         }
     }
@@ -440,7 +450,7 @@ sub check_init {
             if (
                 none { /^(?:\$(?:local|remote)_fs|\$all|umountn?fs)\z/ }
                 @required
-              ) {
+            ) {
                 tag 'init.d-script-missing-dependency-on-local_fs',
                   "${initd_path}: required-stop";
             }
@@ -475,15 +485,52 @@ sub check_init {
           $initd_path, $option;
     }
 
-    for my $option (qw(status)) {
-        $tag{$option}
-          or tag 'init.d-script-does-not-implement-optional-option',
-          $initd_path, $option;
-    }
+    tag 'init.d-script-does-not-implement-status-option', $initd_path
+      unless $tag{'status'};
 
     return;
 }
 
+sub check_defaults {
+    my ($info) = @_;
+    my $dir = $info->index_resolved_path('etc/default/');
+    return unless $dir and $dir->is_dir;
+    for my $path ($dir->children) {
+        return if not $path->is_open_ok;
+        my $fd = $path->open;
+        while (<$fd>) {
+            tag 'init.d-script-should-always-start-service', $path, "(line $.)"
+              if m/^\s*#*\s*(?:ENABLED|DISABLED|[A-Z]*RUN)=/;
+        }
+        close($fd);
+    }
+    return;
+}
+
+# Check for missing init.d script, when equivalent for alternative init
+# system is present.
+sub check_missing_script {
+    my ($info) = @_;
+    for my $file ($info->sorted_index) {
+        if (   $file =~ m,etc/sv/([^/]+)/run$,
+            or $file =~ m,lib/systemd/system/(.*)\.service,) {
+
+            my $service = $1;
+            tag 'package-supports-alternative-init-but-no-init.d-script',$file
+              unless $info->index_resolved_path("etc/init.d/${service}");
+        }
+
+        if ($file =~ m,etc/sv/([^/]+)/$,) {
+            my $service = $1;
+            my $file = $info->index_resolved_path("etc/sv/${service}/run");
+            tag 'directory-in-etc-sv-directory-without-executable-run-script',
+              $file
+              if not $file or not $file->is_executable;
+        }
+    }
+    return;
+}
+
 1;
 
 # Local Variables:
