@@ -32,6 +32,7 @@ use Lintian::Relation::Version qw(versions_lte);
 my @FIELDS = qw(Depends Pre-Depends Recommends Suggests);
 my @IGNORE = qw(-dev$ -docs?$ -common$ -tools$);
 my @PYTHON2 = qw(python python2.7 python-dev);
+my @PYTHON3 = qw(python3 python3-dev);
 
 my %DJANGO_PACKAGES = (
     '^python3-django-' => 'python3-django',
@@ -134,7 +135,7 @@ sub _run_source {
                             && $pyversion[1] =~ /^$rule->[1]$/
                         )
                         || (!$pyversion[1] && !$rule->[1]))
-                  ) {
+                ) {
                     $okay = 1;
                     last;
                 }
@@ -144,8 +145,8 @@ sub _run_source {
 
         if ($pyversion =~ /\b(([23])\.\d+)$/) {
             my ($v, $major) = ($1, $2);
-            my $old = $VERSIONS->value("stable-python$major");
-            my $ancient = $VERSIONS->value("oldstable-python$major");
+            my $old = $VERSIONS->value("old-python$major");
+            my $ancient = $VERSIONS->value("ancient-python$major");
 
             if (versions_lte($v, $ancient)) {
                 tag 'ancient-python-version-field', $field, $v;
@@ -155,6 +156,10 @@ sub _run_source {
         }
     }
 
+    tag 'source-package-encodes-python-version'
+      if $info->name =~ m/^python\d-/
+      and $info->name ne 'python3-defaults';
+
     return;
 }
 
@@ -163,7 +168,10 @@ sub _run_binary {
 
     my $deps = Lintian::Relation->and($info->relation('all'),
         $info->relation('provides'), $pkg);
-    my @entries = $info->changelog ? $info->changelog->data : ();
+    my @entries
+      = $info->changelog
+      ? @{$info->changelog->entries}
+      : ();
 
     # Check for missing dependencies
     if ($pkg !~ /-dbg$/) {
@@ -178,6 +186,20 @@ sub _run_binary {
         }
     }
 
+    # Check for duplicate dependencies
+    for my $field (@FIELDS) {
+        my $dep = $info->relation($field);
+      FIELD: for my $py2 (@PYTHON2) {
+            for my $py3 (@PYTHON3) {
+                if ($dep->implies("$py2:any") and $dep->implies("$py3:any")) {
+                    tag 'depends-on-python2-and-python3',
+                      "$field: $py2, [..], $py3";
+                    last FIELD;
+                }
+            }
+        }
+    }
+
     # Python 2 modules
     if (    $pkg =~ /^python2?-/
         and none { $pkg =~ /$_$/ } @IGNORE
@@ -227,6 +249,17 @@ sub _run_binary {
         }
     }
 
+    for my $file ($info->sorted_index) {
+        next unless $file->is_file;
+        next unless $file->is_open_ok;
+        next unless $file =~ m,(usr/)?bin/[^/]+,;
+        my $fd = $file->open();
+        my $line = <$fd>;
+        tag 'script-uses-unversioned-python-in-shebang', $file
+          if $line && $line =~ m,^#!\s*(/usr/bin/env\s*)?(/usr/bin/)?python$,;
+        close($fd);
+    }
+
     return;
 }
 
